==> boo_0.8.2.2960+dfsg.orig.tar.gz: boo-0.8.2.2960+dfsg/src/Boo.Lang.Parser/BooTokenTypes.cs <==
﻿#region license
// Copyright (c) 2003, 2004, 2005 Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion


// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/boo.g" -> "BooParserBase.cs"$

namespace Boo.Lang.Parser
{
	public class BooTokenTypes
	{
		public const int EOF = 1;
		public const int NULL_TREE_LOOKAHEAD = 3;
		public const int INDENT = 4;
		public const int DEDENT = 5;
		public const int ELIST = 6;
		public const int DLIST = 7;
		public const int ESEPARATOR = 8;
		public const int EOL = 9;
		public const int ABSTRACT = 10;
		public const int AND = 11;
		public const int AS = 12;
		public const int BREAK = 13;
		public const int CONTINUE = 14;
		public const int CALLABLE = 15;
		public const int CAST = 16;
		public const int CHAR = 17;
		public const int CLASS = 18;
		public const int CONSTRUCTOR = 19;
		public const int DEF = 20;
		public const int DESTRUCTOR = 21;
		public const int DO = 22;
		public const int ELIF = 23;
		public const int ELSE = 24;
		public const int ENSURE = 25;
		public const int ENUM = 26;
		public const int EVENT = 27;
		public const int EXCEPT = 28;
		public const int FAILURE = 29;
		public const int FINAL = 30;
		public const int FROM = 31;
		public const int FOR = 32;
		public const int FALSE = 33;
		public const int GET = 34;
		public const int GOTO = 35;
		public const int IMPORT = 36;
		public const int INTERFACE = 37;
		public const int INTERNAL = 38;
		public const int IS = 39;
		public const int ISA = 40;
		public const int IF = 41;
		public const int IN = 42;
		public const int NOT = 43;
		public const int NULL = 44;
		public const int OF = 45;
		public const int OR = 46;
		public const int OVERRIDE = 47;
		public const int PASS = 48;
		public const int NAMESPACE = 49;
		public const int PARTIAL = 50;
		public const int PUBLIC = 51;
		public const int PROTECTED = 52;
		public const int PRIVATE = 53;
		public const int RAISE = 54;
		public const int REF = 55;
		public const int RETURN = 56;
		public const int SET = 57;
		public const int SELF = 58;
		public const int SUPER = 59;
		public const int STATIC = 60;
		public const int STRUCT = 61;
		public const int THEN = 62;
		public const int TRY = 63;
		public const int TRANSIENT = 64;
		public const int TRUE = 65;
		public const int TYPEOF = 66;
		public const int UNLESS = 67;
		public const int VIRTUAL = 68;
		public const int WHILE = 69;
		public const int YIELD = 70;
		public const int TRIPLE_QUOTED_STRING = 71;
		public const int EOS = 72;
		public const int DOUBLE_QUOTED_STRING = 73;
		public const int SINGLE_QUOTED_STRING = 74;
		public const int ID = 75;
		public const int LBRACK = 76;
		public const int RBRACK = 77;
		public const int LPAREN = 78;
		public const int RPAREN = 79;
		public const int ASSIGN = 80;
		public const int SUBTRACT = 81;
		public const int COMMA = 82;
		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 83;
		public const int SPLICE_BEGIN = 84;
		public const int DOT = 85;
		public const int COLON = 86;
		public const int MULTIPLY = 87;
		public const int NULLABLE_SUFFIX = 88;
		public const int BITWISE_OR = 89;
		public const int LBRACE = 90;
		public const int RBRACE = 91;
		public const int QQ_BEGIN = 92;
		public const int QQ_END = 93;
		public const int INPLACE_BITWISE_OR = 94;
		public const int INPLACE_BITWISE_AND = 95;
		public const int INPLACE_SHIFT_LEFT = 96;
		public const int INPLACE_SHIFT_RIGHT = 97;
		public const int CMP_OPERATOR = 98;
		public const int GREATER_THAN = 99;
		public const int LESS_THAN = 100;
		public const int ADD = 101;
		public const int EXCLUSIVE_OR = 102;
		public const int DIVISION = 103;
		public const int MODULUS = 104;
		public const int BITWISE_AND = 105;
		public const int SHIFT_LEFT = 106;
		public const int SHIFT_RIGHT = 107;
		public const int EXPONENTIATION = 108;
		public const int INCREMENT = 109;
		public const int DECREMENT = 110;
		public const int ONES_COMPLEMENT = 111;
		public const int INT = 112;
		public const int LONG = 113;
		public const int RE_LITERAL = 114;
		public const int DOUBLE = 115;
		public const int FLOAT = 116;
		public const int TIMESPAN = 117;
		public const int LINE_CONTINUATION = 118;
		public const int SL_COMMENT = 119;
		public const int ML_COMMENT = 120;
		public const int WS = 121;
		public const int X_RE_LITERAL = 122;
		public const int NEWLINE = 123;
		public const int ESCAPED_EXPRESSION = 124;
		public const int DQS_ESC = 125;
		public const int SQS_ESC = 126;
		public const int SESC = 127;
		public const int RE_CHAR = 128;
		public const int X_RE_CHAR = 129;
		public const int RE_ESC = 130;
		public const int DIGIT_GROUP = 131;
		public const int REVERSE_DIGIT_GROUP = 132;
		public const int ID_PREFIX = 133;
		public const int ID_LETTER = 134;
		public const int DIGIT = 135;
		public const int HEXDIGIT = 136;
		
	}
}

==> boo_0.9.2.3383+dfsg.orig.tar.gz: boo-0.9.2.3383+dfsg/src/Boo.Lang.Parser/BooTokenTypes.cs <==
﻿#region license
// Copyright (c) 2003, 2004, 2005 Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion


// $ANTLR 2.7.5 (20050517): "src/Boo.Lang.Parser/boo.g" -> "BooParserBase.cs"$

namespace Boo.Lang.Parser
{
	public class BooTokenTypes
	{
		public const int EOF = 1;
		public const int NULL_TREE_LOOKAHEAD = 3;
		public const int INDENT = 4;
		public const int DEDENT = 5;
		public const int ELIST = 6;
		public const int DLIST = 7;
		public const int ESEPARATOR = 8;
		public const int EOL = 9;
		public const int ABSTRACT = 10;
		public const int AND = 11;
		public const int AS = 12;
		public const int BREAK = 13;
		public const int CONTINUE = 14;
		public const int CALLABLE = 15;
		public const int CAST = 16;
		public const int CHAR = 17;
		public const int CLASS = 18;
		public const int CONSTRUCTOR = 19;
		public const int DEF = 20;
		public const int DESTRUCTOR = 21;
		public const int DO = 22;
		public const int ELIF = 23;
		public const int ELSE = 24;
		public const int ENSURE = 25;
		public const int ENUM = 26;
		public const int EVENT = 27;
		public const int EXCEPT = 28;
		public const int FAILURE = 29;
		public const int FINAL = 30;
		public const int FROM = 31;
		public const int FOR = 32;
		public const int FALSE = 33;
		public const int GET = 34;
		public const int GOTO = 35;
		public const int IMPORT = 36;
		public const int INTERFACE = 37;
		public const int INTERNAL = 38;
		public const int IS = 39;
		public const int ISA = 40;
		public const int IF = 41;
		public const int IN = 42;
		public const int NOT = 43;
		public const int NULL = 44;
		public const int OF = 45;
		public const int OR = 46;
		public const int OVERRIDE = 47;
		public const int PASS = 48;
		public const int NAMESPACE = 49;
		public const int PARTIAL = 50;
		public const int PUBLIC = 51;
		public const int PROTECTED = 52;
		public const int PRIVATE = 53;
		public const int RAISE = 54;
		public const int REF = 55;
		public const int RETURN = 56;
		public const int SET = 57;
		public const int SELF = 58;
		public const int SUPER = 59;
		public const int STATIC = 60;
		public const int STRUCT = 61;
		public const int THEN = 62;
		public const int TRY = 63;
		public const int TRANSIENT = 64;
		public const int TRUE = 65;
		public const int TYPEOF = 66;
		public const int UNLESS = 67;
		public const int VIRTUAL = 68;
		public const int WHILE = 69;
		public const int YIELD = 70;
		public const int ID = 71;
		public const int TRIPLE_QUOTED_STRING = 72;
		public const int EOS = 73;
		public const int DOUBLE_QUOTED_STRING = 74;
		public const int SINGLE_QUOTED_STRING = 75;
		public const int LBRACK = 76;
		public const int RBRACK = 77;
		public const int LPAREN = 78;
		public const int RPAREN = 79;
		public const int ASSIGN = 80;
		public const int COMMA = 81;
		public const int ASSEMBLY_ATTRIBUTE_BEGIN = 82;
		public const int SPLICE_BEGIN = 83;
		public const int DOT = 84;
		public const int COLON = 85;
		public const int MULTIPLY = 86;
		public const int NULLABLE_SUFFIX = 87;
		public const int BITWISE_OR = 88;
		public const int LBRACE = 89;
		public const int RBRACE = 90;
		public const int QQ_BEGIN = 91;
		public const int QQ_END = 92;
		public const int INPLACE_BITWISE_OR = 93;
		public const int INPLACE_EXCLUSIVE_OR = 94;
		public const int INPLACE_BITWISE_AND = 95;
		public const int INPLACE_SHIFT_LEFT = 96;
		public const int INPLACE_SHIFT_RIGHT = 97;
		public const int CMP_OPERATOR = 98;
		public const int GREATER_THAN = 99;
		public const int LESS_THAN = 100;
		public const int ADD = 101;
		public const int SUBTRACT = 102;
		public const int EXCLUSIVE_OR = 103;
		public const int DIVISION = 104;
		public const int MODULUS = 105;
		public const int BITWISE_AND = 106;
		public const int SHIFT_LEFT = 107;
		public const int SHIFT_RIGHT = 108;
		public const int EXPONENTIATION = 109;
		public const int INCREMENT = 110;
		public const int DECREMENT = 111;
		public const int ONES_COMPLEMENT = 112;
		public const int INT = 113;
		public const int LONG = 114;
		public const int RE_LITERAL = 115;
		public const int DOUBLE = 116;
		public const int FLOAT = 117;
		public const int TIMESPAN = 118;
		public const int LINE_CONTINUATION = 119;
		public const int SL_COMMENT = 120;
		public const int ML_COMMENT = 121;
		public const int WS = 122;
		public const int X_RE_LITERAL = 123;
		public const int NEWLINE = 124;
		public const int ESCAPED_EXPRESSION = 125;
		public const int DQS_ESC = 126;
		public const int SQS_ESC = 127;
		public const int SESC = 128;
		public const int RE_CHAR = 129;
		public const int X_RE_CHAR = 130;
		public const int RE_OPTIONS = 131;
		public const int RE_ESC = 132;
		public const int DIGIT_GROUP = 133;
		public const int REVERSE_DIGIT_GROUP = 134;
		public const int ID_PREFIX = 135;
		public const int ID_LETTER = 136;
		public const int DIGIT = 137;
		public const int HEXDIGIT = 138;
		
	}
}
